package handlers

import "github.com/labstack/echo/v4"

func SetupRoutes(app *echo.Echo, h *UserHandler) {
	group := app.Group("/user")

	group.GET("", h.HandlerShowUsers)
	group.GET("/details/:id", h.HandlerShowUserById)

}

//PLAYGROUND TESTING
func SetupRoutesLogin(app *echo.Echo, h *LoginHandler) {
	l := app.Group("/login")
	l.GET("/", h.HandlerShowLogin)
}
func SetupRoutesXsample(app *echo.Echo, h *XsampleHandler) {
	xSample := app.Group("/xsample")
	xSample.GET("/xsample01", h.Hello)
	xSample.GET("/coba", h.ShowCoba)
	xSample.GET("/counter", h.ShowCounter)
	xSample.GET("/counterchange", h.ChangeCounter)
}
func SetupRoutesLandingPage(app *echo.Echo, h *LandingPageHandler, mastermenuusergroupHandler *MasterMenuUserGroupHandler) {
	Lp := app.Group("/landing_page")
	Lp.GET("/", h.ShowLandingPage)
	clientgroup := app.Group("/client")
	// mdgroup := clientgroup.Group("/md")
	// clientusergroup.GET("/md", mastermenuusergroupHandler.HandlerShowMasterMenuUserGroup)
	clientgroup.GET("/usergroup", mastermenuusergroupHandler.HandlerShowMasterMenuUserGroup)
	clientgroup.GET("/usergroup/edit", mastermenuusergroupHandler.ChangeFormEdit)

}
func SetupRoutesPieChart(app *echo.Echo, h *PiechartHandler) {
	Lp := app.Group("/pie_chart")
	Lp.GET("/", h.ShowPieChart)
	Lp.GET("/peserta", h.ShowMcuPeserta)
	Lp.GET("/bar", h.ShowBarChart)
}
func SetupRoutesEmployee(app *echo.Echo, e *EmployeeHandler) {
	employee := app.Group("/employee")
	employee.GET("/", e.ShowEmployee)
}
func SetupRoutesProject(app *echo.Echo) {

}
